@@ -10,7 +10,10 @@ function (behavior,phaseX,v1,v2) {
   
   
   num<-ctbl[4]
-  nl<-c("There are", as.character(num),"values below the median line in the intervention.")
+  pre<-(prop.table(ctbl,2)*100)
+  numpre<-pre[4]
+  nl<-c("There are", as.character(num),"value(s)","(",as.character(round(numpre,2)), "percent) below the median line in the intervention.")
+  
   colnames (ctbl)<-c("Baselene", "Intervention")
   
   writeLines(" ")
@@ -18,11 +21,13 @@ function (behavior,phaseX,v1,v2) {
   cat(sprintf(nl),"\n")
   
   writeLines(" ")
+  writeLines("Frequencies")
   print(ctbl)
-  
   writeLines(" ")
+  writeLines("Row Percent")
   print(prop.table(ctbl,1)*100)
   writeLines(" ")
+  writeLines("Column Percent")
   print(prop.table(ctbl,2)*100)
   writeLines(" ")
   c1<-chisq.test(ctbl,simulate.p.value = TRUE)
