@@ -64,7 +64,9 @@ function(behavior,phaseX, v1,v2){
   num<-(ctbl[4]) 
        
   
-  nl<-c("There are", as.character(num),"values below the regression line in the intervention.")
+  pre<-(prop.table(ctbl,2)*100)
+  numpre<-pre[4]
+  nl<-c("There are", as.character(num),"value(s)","(",as.character(round(numpre,2)), "percent) below the regression line in the intervention.")
   
   
   colnames (ctbl)<-c("Baselene", "Intervention")
@@ -75,12 +77,17 @@ function(behavior,phaseX, v1,v2){
   
   
   writeLines(" ")
+  writeLines("Frequencies ")
   print(ctbl)
+  
   writeLines(" ")
+  writeLines("Row Percent")
   print(prop.table(ctbl,1)*100)
   writeLines(" ")
+  writeLines("Column Percent")
   print(prop.table(ctbl,2)*100)
   writeLines(" ")
+  
   c1<-chisq.test(ctbl,simulate.p.value = TRUE)
    
   
