@@ -29,13 +29,16 @@ function(behavior,phaseX,v1,ABxlab,ABylab,ABmain){
   #par(mar=c(1, 1, 1, 1))
   #plot.new()
   #legend("center", c("+2sd","mean","-2sd"), col = c("blue","orange", "red"), lwd = 1,ncol=3,bty ="n")
-  sd1<-c("SD=",round(sdA,2))
-  psdu<-c("+2sd=",round(SDabove,2))
-  pmean<-c("mean=",round(meanA,2))
-  psdb<-c("-2SD=",round(SDbelow,2))
-  print(sd1)
-  print(psdu)
-  print(pmean)
-  print(psdb)
+  sd1<-c("  SD =",round(sdA,2))
+  psdu<-c("+2sd =",round(SDabove,2))
+  pmean<-c("mean =",round(meanA,2))
+  psdb<-c("-2SD =",round(SDbelow,2))
+  writeLines(" ")
+  tprint=c(sd1,psdu,pmean,psdb)
+  #print(sd1)
+  #print(psdu)
+  #print(pmean)
+  #print(psdb)
+  cat(sprintf(tprint),"\n") 
   
 }
